import React, { useEffect, useState, useRef } from "react";
import { register } from "@antv/x6-react-shape";
import { Graph, Node } from "@antv/x6";
import { Input } from "antd";
import { useSize } from 'ahooks';

const NoticeNode = ({ node, graph }: { node: Node; graph: Graph }) => {
  const { style, name, text, id } = node.getData();
  const boxRef = useRef<HTMLDivElement>(null);
  const { width: w, height: h } = useSize(boxRef) || node.getSize();

  const strokeWidth = 1;
  return (
    <>
      <div className="relative w-full h-full" ref={boxRef}>
        <svg
          className="absolute top-0 left-0"
          viewBox={`0 0 ${w} ${h}`}
          xmlns="http://www.w3.org/2000/svg"
        >
          <path
            d={`
              M ${strokeWidth},${strokeWidth}
              L ${w - 20},${strokeWidth}
              L ${w - strokeWidth},${20}
              L ${w - strokeWidth},${h - strokeWidth}
              L ${strokeWidth},${h - strokeWidth}
              L ${strokeWidth},${strokeWidth}
              Z
            `}
            fill={style.background}
            stroke="#666"
            strokeWidth={strokeWidth}
          />
          <path
            d={`
              M ${w - 20},${strokeWidth}
              L ${w - 20},${20}
              L ${w - strokeWidth},${20}
              L ${w - 20},${strokeWidth} Z
            `}
            fill={style.background}
            stroke="#666"
            strokeWidth={strokeWidth}
          />
        </svg>
        <div className="absolute w-full h-full flex flex-col">
          <div className="color-#333 px-20px py-4px">{name}</div>
          <Input.TextArea
            variant="borderless"
            className="w-full resize-none! flex-1 color-#666"
            value={text}
            key={id}
            onChange={(e) => node.prop('update:remark', { ...node.getData(), text: e.target.value })}
          />
        </div>
      </div>
    </>
  );
};

register({
  shape: "notice-node",
  component: NoticeNode,
  width: 300,
  height: 300,
  effect: ["data"],
});
