import React, { useEffect } from "react";
import { Input, Layout, Tabs, ConfigProvider } from "antd";
import type { TabsProps } from "antd/lib";
import Toolbar from "./components/Toolbar";
import TablePanel from "./components/TablePanel";
import RelationPanel from "./components/RelationPanel";
import ThemePanel from "./components/ThemePanel";
import RemarkPanel from "./components/RemarkPanel";
import Navigator from "./components/Navigator";
import Menu from "./components/Menu";
import { useModel } from "umi";
import "./index.less";

const { Header, Content, Sider } = Layout;

const App: React.FC = () => {
  const containerRef = React.useRef(null);
  const { initGraph, project } = useModel("erModel");

  useEffect(() => {
    if (containerRef.current) {
      initGraph(containerRef.current);
    }
  }, []);

  const tabItems: TabsProps["items"] = [
    {
      key: "1",
      label: "表",
      children: <TablePanel />,
    },
    {
      key: "2",
      label: "关系",
      children: <RelationPanel />,
    },
    {
      key: "3",
      label: "主题区域",
      children: <ThemePanel />,
    },
    {
      key: "4",
      label: "注释",
      children: <RemarkPanel />,
    },
  ];

  return (
    <Layout className="h-100vh">
      <Header
        className="bg-white h-100px border-b-1px border-b-solid border-b-gray-200 p-x-0 flex flex-col"
        style={{
          height: project.setting.showMenu ? "100px" : "32px",
          transition: "all 0.3s ease-in-out",
        }}
      >
        <div
          className="grid"
          style={{ 
            gridTemplateRows: project.setting.showMenu ? "1fr" : "0fr",
            transition: 'all 0.3s'
          }}
        >
          <div className="overflow-hidden">
            <Menu />
          </div>
        </div>
        <Toolbar />
      </Header>
      <Layout>
        <Sider
          width={project.setting.showSidebar ? 360 : 0}
          style={{ background: "#fff", borderRight: "1px solid #eee" }}
        >
          <ConfigProvider
            theme={{
              components: {
                Tabs: {
                  colorPrimary: "#000",
                },
              },
            }}
          >
            <Tabs animated items={tabItems} centered />
          </ConfigProvider>
        </Sider>
        <Layout>
          <Content>
            <div id="graph-container" ref={containerRef}></div>
            <Navigator />
          </Content>
        </Layout>
      </Layout>
    </Layout>
  );
};

export default App;
