import { PlusOutlined } from "@ant-design/icons";
import { ProConfigProvider, ProLayout } from "@ant-design/pro-components";
import { css } from "@emotion/css";
import { Space, Button, ConfigProvider, Popover } from "antd";
import React, { useMemo, useRef, useState } from "react";
import { Icon } from "umi";
// import All from "./All";
import Collect from "./Collect";
import Template from "./Template";

export default () => {
  const currentFolder = useRef("root");
  const [updateKey, setUpdateKey] = useState(0);


  const handleMenuClick = (item: any) => {
    console.log("click", item);
    item?.onClick?.();
  };

  const renderBasicItem = (props: {
    title: string;
    subtitle: string;
    color: string;
    id: string;
    icon: React.ReactNode;
  }) => {
    return (
      <div
        key={props.id}
        className={css`
          width: 136px;
          height: 60px;
          padding: 8px;
          border-radius: 8px;
          display: flex;
          align-items: center;
          cursor: pointer;
          margin-top: 8px;
          background: ${props.color + "70"};
          &:hover {
            background: ${props.color};
          }
        `}
        onClick={() => handleMenuClick(props)}
      >
        <span className="w-32px h-33px">{props.icon}</span>
        <div className="flex flex-col justify-center ml-4px">
          <div className="text-14px">{props.title}</div>
          <div className="text-12px text-#9aa5b8">{props.subtitle}</div>
        </div>
      </div>
    );
  };

  const renderProItem = (props: {
    id: string;
    title: string;
    icon: React.ReactNode;
  }) => {
    return (
      <div
        key={props.id}
        className="w-66px h-70px flex flex-col items-center justify-center mt-8px rounded-lg hover:bg-#f3f5f9 cursor-pointer"
        onClick={() => handleMenuClick(props)}
      >
        {props.icon}
        <span className="text-12px">{props.title}</span>
      </div>
    );
  };

  const handleChangeFolder = (id: string) => {
    currentFolder.current = id;
  };

  const [pathname, setPathname] = useState("/all");
  const routes = [
    {
      path: "/all",
      name: "全部",
      icon: <i className="iconfont icon-xitong" />,
      component: (
        // <All onChangeCurrentFolder={handleChangeFolder} updateKey={updateKey} />
        <div></div>
      ),
    },
    {
      path: "/recently",
      name: "模型市场",
      icon: <i className="iconfont icon-shijian" />,
      component: <div></div>
    },
    {
      path: "/template",
      name: "我的模版",
      icon: <i className="iconfont icon-yingyong" />,
      component: <Template />,
    },
    {
      path: "/collect",
      name: "我的收藏",
      icon: <i className="iconfont icon-xihuan" />,
      component: <Collect />,
    },
  ];

  const content = useMemo(() => {
    currentFolder.current = "root";
    return routes.find((item) => item.path === pathname)?.component;
  }, [pathname, updateKey]);

  return (
    <div
      id="test-pro-layout"
      style={{
        height: "100vh",
        overflow: "auto",
      }}
    >
      <ProLayout
        headerTitleRender={() => null}
        logo={false}
        title={"系统设计"}
        location={{ pathname }}
        route={{
          routes,
        }}
        bgLayoutImgList={[
          {
            src: "https://img.alicdn.com/imgextra/i2/O1CN01O4etvp1DvpFLKfuWq_!!6000000000279-2-tps-609-606.png",
            left: 85,
            bottom: 100,
            height: "303px",
          },
          {
            src: "https://img.alicdn.com/imgextra/i2/O1CN01O4etvp1DvpFLKfuWq_!!6000000000279-2-tps-609-606.png",
            bottom: -68,
            right: -45,
            height: "303px",
          },
          {
            src: "https://img.alicdn.com/imgextra/i3/O1CN018NxReL1shX85Yz6Cx_!!6000000005798-2-tps-884-496.png",
            bottom: 0,
            left: 0,
            width: "331px",
          },
        ]}
        menuItemRender={(item, dom) => (
          <div
            onClick={() => {
              setPathname(item.path || "/all");
            }}
          >
            {dom}
          </div>
        )}
      >
        <ProConfigProvider hashed={false}>
          <ConfigProvider
            getTargetContainer={() => {
              return (
                document.getElementById("test-pro-layout") || document.body
              );
            }}
          >
            {content}
          </ConfigProvider>
        </ProConfigProvider>
      </ProLayout>
    </div>
  );
};
