/**
 * 字段结构
 */
export interface ColumnItem {
  aggregateEnable?: boolean;
  businessTableId?: string;
  charset?: string;
  cn_name: string;
  defaultValue: any;
  displayEnable?: boolean;
  displayOrder?: number;
  en_name: string;
  groupByEnable?: boolean;
  id: string;
  isAggregateEnable?: boolean;
  isDisplayEnable?: boolean;
  isGroupByEnable?: boolean;
  isLinkEnable?: boolean;
  isOrderByEnable?: boolean;
  isPreDefined?: boolean;
  isRequired: boolean;
  isUnique: boolean;
  isWhereEnable?: boolean;
  linkEnable?: boolean;
  maxLength?: number;
  name: string;
  orderByEnable?: boolean;
  preDefined?: boolean;
  precision?: number;
  required?: boolean;
  scale?: number;
  schemaName?: string;
  type: number;
  unique?: boolean;
  whereEnable?: boolean;
  langName?: string;
}

/**
 * 表结构
 */
export interface ViewTable {
  aliasName: string;
  creationTime: string;
  creatorUserId: string;
  displayOrder: number;
  id: string;
  isDeleted: boolean;
  langDescription: string;
  langName: string;
  name: string;
  parentBusinessTableId: string;
  schemaName: string;
  type: number;
  updateTime: string;
  cn_name: string;
  en_name: string;
}

/**
 * 字段关系
 */
export interface ColumnRelation {
  id: string;
  // 名称
  name: string;
  // 主键
  primaryKey: string;
  // 主键表
  primaryTable: string;
  // 外键
  foreignKey: string;
  // 外键表
  foreignTable: string;
  // 关系类型 1 一对一 2 一对多 3 多对一 4 多对多
  relationType: 1 | 2 | 3 | 4;
  // 连线样式
  style: Record<string, any>;
}

/**
 * 主题区域信息
 */
export interface TopicAreaInfo {
  // 主题区域id
  id: string;
  // 主题区域名称
  name: string;
  // 主题区域样式
  style: Record<string, any>;
  isTopicArea: boolean;
}

/**
 * 注释信息
 */
export interface RemarkInfo {
  id: string;
  // 名称
  name: string;
  // 内容
  text: string;
  // 样式
  style: {
    x: number;
    y: number;
    width: number;
    height: number;
    background: string;
  };
  isRemark: boolean;
}

/**
 * 表数据
 */
export type TableItemType = {
  table: ViewTable & {openSync: boolean; style: Record<string, any>},
  tableColumnList: ColumnItem[],
  isTable: boolean;
};

/**
 * 数据模型项目信息
 */
export interface ProjectInfo {
  id: string;
  // 名称
  name: string;
  // 文件夹ID
  folderId: string;
  // 创建时间
  creationTime: string;
  // 创建者
  creatorUser: string;
  // 更新时间
  lastModificationTime: string;
  // 模型说明
  description?: string;
  // 是否模版
  isTemplate: boolean;
  // 所属行业
  industry?: string;
  // 发布状态
  publishStatus: string;
  // 数据表 openSync 开启同步
  tables: TableItemType[];
  // 关系
  relations: ColumnRelation[];
  // 主题区域
  topicAreas: TopicAreaInfo[];
  // 注释节点
  remarks: RemarkInfo[];
  // 操作记录
  history: any[];
  // 画布设置
  setting: {
    // 展示菜单栏
    showMenu: boolean;
    // 展示侧边栏
    showSidebar: boolean;
    // 展示字段详情
    showColumnDetail: boolean;
    // 展示网格
    showGrid: boolean;
    // 展示关系
    showRelation: boolean;
    // 自动更新
    autoUpdate: boolean;
    // 表格宽度
    tableWidth: number;
  }
}
